@@ -18,8 +18,6 @@ import logging
 import time
 import warnings
 
-import six
-
 from ironic_inspector_client.common import http
 from ironic_inspector_client.common.i18n import _
 
@@ -97,7 +95,7 @@ class ClientV1(http.BaseClient):
         """
 
         node_id = node_id or uuid
-        if not isinstance(node_id, six.string_types):
+        if not isinstance(node_id, str):
             raise TypeError(
                 _("Expected string for node_id argument, got %r") % node_id)
         if uuid:
@@ -172,7 +170,7 @@ class ClientV1(http.BaseClient):
             * `started_at` an ISO8601 timestamp,
             * `uuid` the node UUID
         """
-        if not (marker is None or isinstance(marker, six.string_types)):
+        if not (marker is None or isinstance(marker, str)):
             raise TypeError(_('Expected a string value of the marker, got '
                               '%s instead') % marker)
         if not (limit is None or isinstance(limit, int)):
@@ -264,7 +262,7 @@ class ClientV1(http.BaseClient):
         raise WaitTimeoutError(_("Timeout while waiting for introspection "
                                  "of nodes %s") % new_active_node_ids)
 
-    def get_data(self, node_id=None, raw=False, uuid=None):
+    def get_data(self, node_id=None, raw=False, uuid=None, processed=True):
         """Get introspection data from the last introspection of a node.
 
         If swift support is disabled, introspection data won't be stored,
@@ -273,6 +271,8 @@ class ClientV1(http.BaseClient):
         :param uuid: node UUID or name, deprecated
         :param node_id: node node_id or name
         :param raw: whether to return raw binary data or parsed JSON data
+        :param processed: whether to return the final processed data or the
+            raw unprocessed data received from the ramdisk.
         :returns: bytes or a dict depending on the 'raw' argument
         :raises: :py:class:`ironic_inspector_client.ClientError` on error
             reported from a server
@@ -283,7 +283,9 @@ class ClientV1(http.BaseClient):
         """
         node_id = self._check_parameters(node_id, uuid)
 
-        resp = self.request('get', '/introspection/%s/data' % node_id)
+        url = ('/introspection/%s/data' if processed
+               else '/introspection/%s/data/unprocessed')
+        resp = self.request('get', url % node_id)
         if raw:
             return resp.content
         else:
@@ -309,8 +311,8 @@ class ClientV1(http.BaseClient):
         """Get interface data for the input node and interface
 
         To get LLDP data, collection must be enabled by the kernel parameter
-        ``ipa-collect-lldp=1``, and the inspector plugin ``basic_lldp`` must
-        be enabled.
+        ``ipa-collect-lldp=1``, and a relevant inspector plugin must be
+        enabled, e.g., ``lldp_basic``, ``local_link_connection``.
 
         :param node_ident: node UUID or name
         :param interface: interface name
@@ -410,7 +412,7 @@ class RulesAPI(object):
         :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
             requested api_version is not supported
         """
-        if uuid is not None and not isinstance(uuid, six.string_types):
+        if uuid is not None and not isinstance(uuid, str):
             raise TypeError(
                 _("Expected string for uuid argument, got %r") % uuid)
         for name, arg in [('conditions', conditions), ('actions', actions)]:
@@ -459,7 +461,7 @@ class RulesAPI(object):
         :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
             requested api_version is not supported
         """
-        if not isinstance(uuid, six.string_types):
+        if not isinstance(uuid, str):
             raise TypeError(
                 _("Expected string for uuid argument, got %r") % uuid)
         return self._request('get', '/rules/%s' % uuid).json()
@@ -473,7 +475,7 @@ class RulesAPI(object):
         :raises: :py:class:`ironic_inspector_client.VersionNotSupported` if
             requested api_version is not supported
         """
-        if not isinstance(uuid, six.string_types):
+        if not isinstance(uuid, str):
             raise TypeError(
                 _("Expected string for uuid argument, got %r") % uuid)
         self._request('delete', '/rules/%s' % uuid)
